@@ -7,7 +7,7 @@ package Sub::HandlesVia;
 use Exporter::Shiny qw( delegations );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.020';
+our $VERSION   = '0.021';
 
 sub _generate_delegations {
 	my ($me, $name, $args, $globals) = (shift, @_);
@@ -418,24 +418,24 @@ native traits, and L<MouseX::NativeTraits>.
              uniqstr : SubHV                       
     uniqstr_in_place : SubHV                       
              unshift : SubHV  DataP  Moose  Mouse  
- 
+  
   Bool ============================================
                  not : SubHV  DataP  Moose  Mouse  
                reset : SubHV                       
                  set : SubHV  DataP  Moose  Mouse  
               toggle : SubHV  DataP  Moose  Mouse  
                unset : SubHV  DataP  Moose  Mouse  
- 
+  
   Code ============================================
              execute : SubHV  DataP  Moose  Mouse  
       execute_method : SubHV         Moose  Mouse  
- 
+  
   Counter =========================================
                  dec : SubHV  DataP  Moose  Mouse  
                  inc : SubHV  DataP  Moose  Mouse  
                reset : SubHV  DataP  Moose  Mouse  
                  set : SubHV         Moose  Mouse  
- 
+  
   Hash ============================================
             accessor : SubHV  DataP  Moose  Mouse  
                  all : SubHV  DataP                
@@ -459,46 +459,59 @@ native traits, and L<MouseX::NativeTraits>.
          sorted_keys : SubHV                Mouse  
                store :                      Mouse  (alias: set)
               values : SubHV  DataP  Moose  Mouse  
- 
+  
   Number ==========================================
                  abs : SubHV  DataP  Moose  Mouse  
                  add : SubHV  DataP  Moose  Mouse  
+                 cmp : SubHV                       
                  div : SubHV  DataP  Moose  Mouse  
+                  eq : SubHV                       
+                  ge : SubHV                       
                  get : SubHV                       
+                  gt : SubHV                       
+                  le : SubHV                       
+                  lt : SubHV                       
                  mod : SubHV  DataP  Moose  Mouse  
                  mul : SubHV  DataP  Moose  Mouse  
+                  ne : SubHV                       
                  set : SubHV         Moose         
                  sub : SubHV  DataP  Moose  Mouse  
- 
-                 cmp : SubHV                       
-                  eq : SubHV                       
-                  ne : SubHV                       
-                  lt : SubHV                       
-                  le : SubHV                       
-                  gt : SubHV                       
-                  ge : SubHV                       
- 
+  
   Scalar ==========================================
          make_getter : SubHV                       
          make_setter : SubHV                       
     scalar_reference : SubHV                       
- 
+  
   String ==========================================
               append : SubHV  DataP  Moose  Mouse  
                chomp : SubHV  DataP  Moose  Mouse  
                 chop : SubHV  DataP  Moose  Mouse  
                clear : SubHV  DataP  Moose  Mouse  
+                 cmp : SubHV                       
+                cmpi : SubHV                       
             contains : SubHV                       
           contains_i : SubHV                       
            ends_with : SubHV                       
          ends_with_i : SubHV                       
+                  eq : SubHV                       
+                 eqi : SubHV                       
                   fc : SubHV                       
+                  ge : SubHV                       
+                 gei : SubHV                       
                  get : SubHV                       
+                  gt : SubHV                       
+                 gti : SubHV                       
                  inc : SubHV  DataP  Moose  Mouse  
                   lc : SubHV                       
+                  le : SubHV                       
+                 lei : SubHV                       
               length : SubHV  DataP  Moose  Mouse  
+                  lt : SubHV                       
+                 lti : SubHV                       
                match : SubHV  DataP  Moose  Mouse  
              match_i : SubHV                       
+                  ne : SubHV                       
+                 nei : SubHV                       
              prepend : SubHV  DataP  Moose  Mouse  
              replace : SubHV  DataP  Moose  Mouse  
     replace_globally : SubHV                Mouse  
@@ -508,21 +521,16 @@ native traits, and L<MouseX::NativeTraits>.
        starts_with_i : SubHV                       
               substr : SubHV  DataP  Moose  Mouse  
                   uc : SubHV                       
- 
-                 cmp : SubHV                       
-                cmpi : SubHV                       
-                  eq : SubHV                       
-                 eqi : SubHV                       
-                  ne : SubHV                       
-                 nei : SubHV                       
-                  lt : SubHV                       
-                 lti : SubHV                       
-                  le : SubHV                       
-                 lei : SubHV                       
-                  gt : SubHV                       
-                 gti : SubHV                       
-                  ge : SubHV                       
-                 gei : SubHV                       
+
+For further details see:
+L<Array|Sub::HandlesVia::HandlerLibrary::Array>,
+L<Bool|Sub::HandlesVia::HandlerLibrary::Bool>,
+L<Code|Sub::HandlesVia::HandlerLibrary::Code>,
+L<Counter|Sub::HandlesVia::HandlerLibrary::Counter>,
+L<Hash|Sub::HandlesVia::HandlerLibrary::Hash>,
+L<Number|Sub::HandlesVia::HandlerLibrary::Number>,
+L<Scalar|Sub::HandlesVia::HandlerLibrary::Scalar>, and
+L<String|Sub::HandlesVia::HandlerLibrary::String>.
 
 =head2 Method Chaining
 
@@ -663,7 +671,19 @@ L<https://github.com/tobyink/p5-sub-handlesvia/issues>.
 
 =head1 SEE ALSO
 
-L<Moose>, L<MouseX::NativeTraits>, L<Data::Perl>, L<MooX::HandlesVia>.
+Documentation for delegatable methods:
+L<Array|Sub::HandlesVia::HandlerLibrary::Array>,
+L<Bool|Sub::HandlesVia::HandlerLibrary::Bool>,
+L<Code|Sub::HandlesVia::HandlerLibrary::Code>,
+L<Counter|Sub::HandlesVia::HandlerLibrary::Counter>,
+L<Hash|Sub::HandlesVia::HandlerLibrary::Hash>,
+L<Number|Sub::HandlesVia::HandlerLibrary::Number>,
+L<Scalar|Sub::HandlesVia::HandlerLibrary::Scalar>, and
+L<String|Sub::HandlesVia::HandlerLibrary::String>.
+
+Other implementations of the same concept:
+L<Moose::Meta::Attribute::Native>, L<MouseX::NativeTraits>, and
+L<MooX::HandlesVia> with L<Data::Perl>.
 
 =head1 AUTHOR
 
